#pragma once

#include <FL/Fl.H>
#include <FL/Fl_Gl_Window.H>
#include <FL/gl.h>
#include <GL/glu.h>

class ObjectAxes : public Fl_Gl_Window {
public:
	/**
	* Create a new window to display the object in.
	*/
	ObjectAxes(int x,int y,int w,int h,const char *l=0);
	/**
	* The draw() function initializes GL for another round of
	* drawing then calls specialized functions for drawing each
	* of the entities displayed in the axes.
	*/
	void draw();
	/**
	* Set theta, base rotation about y axis.
	*/
	void setTheta(float angle);
	/**
	* Set phi, lower arm rotation about z axis.
	*/
	void setPhi(float angle);
	/**
	* Set psi, upper arm rotation about z axis.
	*/
	void setPsi(float angle);

	/** The cumulative transformations */
	GLfloat m1[16];
	GLfloat m2[16];
	GLfloat m3[16];

	/** The transformation matrices */
	GLfloat mRtheta[16];
	GLfloat mTh1[16];
	GLfloat mRphi[16];
	GLfloat mTh2[16];
	GLfloat mRpsi[16];

private:

	/** angle input values */
	float theta, phi, psi;

	float h1;
	float h2;
	float h3;

	GLfloat boxLower[8][3];
	GLfloat boxUpper[8][3];
	int order[6][4];
	GLfloat normal[6][3];

	GLenum err;

	/** the cylinder */
	GLUquadricObj *qobj;

	void drawObjects(void);

	void base(void);
	void lower_arm(void);
	void upper_arm(void);

	void updateMatrices(void);
	void multiply(GLfloat *A, GLfloat *B);
};
